@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.057-1-g36034a2
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.058';
+# git description: 0.058-9-g9663b18
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.059';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -268,7 +268,7 @@ sub configure {
             -phase        => 'develop',
             -relationship => 'requires',
 
-            $self->meta->name  => $self->VERSION,
+            $self->meta->name  => $self->VERSION || 0,
         } ],
 
         $self->author_tests,
@@ -289,7 +289,7 @@ sub configure {
         }],
         [ CopyFilesFromBuild => { copy => $self->_copy_from_build } ],
 
-        [ 'GitHubREADME::Badge' => { badges => [ qw{ travis cpants } ] } ],
+        [ 'GitHubREADME::Badge' => { badges => [ qw{ travis cpants coveralls } ] } ],
 
         ($self->is_task ? 'TaskWeaver' : $podweaver),
     );
@@ -343,7 +343,7 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Weyl Bowers Neil Romanov Sergey GitHub Plugins
+=for :stopwords Chris Weyl Bowers Neil Romanov Sergey
 
 =for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
@@ -353,7 +353,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.058 of Dist::Zilla::PluginBundle::RSRCHBOY - released April 21, 2015 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.059 of Dist::Zilla::PluginBundle::RSRCHBOY - released April 27, 2015 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -478,7 +478,7 @@ Chris Weyl <cweyl@alumni.drew.edu>
 
 =begin html
 
-<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="https://gratipay.com/RsrchBoy/"><img src="http://img.shields.io/gratipay/RsrchBoy.svg" /></a>
 <a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
 <a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-rsrchboy&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-RSRCHBOY&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-RSRCHBOY%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
 
@@ -489,9 +489,9 @@ rather B<it is simply a very pleasant surprise>. I largely create and release
 works like this because I need them or I find it enjoyable; however, don't let
 that stop you if you feel like it ;)
 
-L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-rsrchboy&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-RSRCHBOY&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-RSRCHBOY%20in%20the%20CPAN%22>,
-L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
+L<Flattr|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-rsrchboy&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-RSRCHBOY&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-RSRCHBOY%20in%20the%20CPAN%22>,
+L<Gratipay|https://gratipay.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If and *only* if you so desire.
 
 =head1 CONTRIBUTORS
 
